searchData={"items":[{"type":"module","title":"Membrane.HTTPAdaptiveStream.Sink","doc":"Sink for generating HTTP streaming manifests.\n\nUses `Membrane.HTTPAdaptiveStream.Manifest` for manifest serialization\nand `Membrane.HTTPAdaptiveStream.Storage` for saving files.","ref":"Membrane.HTTPAdaptiveStream.Sink.html"},{"type":"module","title":"Notifications - Membrane.HTTPAdaptiveStream.Sink","doc":"- `{:track_playable, input_pad_id}` - sent when the first segment of a track is\n  stored, and thus the track is ready to be played","ref":"Membrane.HTTPAdaptiveStream.Sink.html#module-notifications"},{"type":"module","title":"Examples - Membrane.HTTPAdaptiveStream.Sink","doc":"The following configuration:\n\n%Membrane.HTTPAdaptiveStream.Sink{\n      manifest_config: %ManifestConfig{name: \"manifest\", module: Membrane.HTTPAdaptiveStream.HLS}\n      storage: %Membrane.HTTPAdaptiveStream.Storages.FileStorage{directory: \"output\"}\n    }\n\nwill generate a HLS manifest in the `output` directory, playable from\n`output/manifest.m3u8` file.","ref":"Membrane.HTTPAdaptiveStream.Sink.html#module-examples"},{"type":"module","title":"Element options - Membrane.HTTPAdaptiveStream.Sink","doc":"Passed via struct `t:Membrane.HTTPAdaptiveStream.Sink.t/0`\n\n- `manifest_config`  \n\n  ```\n  ManifestConfig.t()\n  ```\n  \n  ***Required***  \n  \n\n\n- `track_config`  \n\n  ```\n  TrackConfig.t()\n  ```\n  \n  ***Required***  \n  \n\n\n\n- `storage`  \n\n  ```\n  Storage.config_t()\n  ```\n  \n  ***Required***  \n  Storage configuration. May be one of `Membrane.HTTPAdaptiveStream.Storages.*`.\n  See `Membrane.HTTPAdaptiveStream.Storage` behaviour.\n\n\n\n- `cleanup_after`  \n\n  ```\n  nil | Membrane.Time.t()\n  ```\n  \n  Default value: `nil`  \n  If not `nil`, time after a storage cleanup function should run.\n  \n  The function will remove all manifests and segments stored during the stream.","ref":"Membrane.HTTPAdaptiveStream.Sink.html#module-element-options"},{"type":"module","title":"Pads - Membrane.HTTPAdaptiveStream.Sink","doc":"### `:input`\n\nAccepted formats:\n```\nCMAF.Track\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nFlow control: | `:manual`\nDemand unit: | `:buffers`\nPad options:\n\n- `track_name`  \n\n  ```\n  String.t() | nil\n  ```\n  \n  Default value: `nil`  \n  Name that will be used to name the media playlist for the given track, as well as its header and segments files.\n  It must not contain any URI reserved characters.\n\n\n- `segment_duration`  \n\n  ```\n  Membrane.Time.t()\n  ```\n  \n  ***Required***  \n  The minimal duration of media segments produced by this particular track.\n  \n  In case of regular paced streams the parameter may not have any impact, but when\n  partial segments gets used it may decide when regular segments gets finalized and new gets started.\n\n\n\n- `partial_segment_duration`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  The target duration of partial segments.\n  \n  When set to nil then the track is not supposed to emit partial segments.\n\n\n\n- `max_framerate`  \n\n  ```\n  float() | nil\n  ```\n  \n  Default value: `nil`  \n  The maximal framerate of video variant. This information is used in master playlist.\n  \n  When set to nil then this information won't be added to master playlist. For audio it should be set to nil.","ref":"Membrane.HTTPAdaptiveStream.Sink.html#module-pads"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Sink.options/0","doc":"Returns description of options available for this module","ref":"Membrane.HTTPAdaptiveStream.Sink.html#options/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Sink.input_pad_opts/0","doc":"Options for pad `:input`","ref":"Membrane.HTTPAdaptiveStream.Sink.html#t:input_pad_opts/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Sink.t/0","doc":"Struct containing options for `Membrane.HTTPAdaptiveStream.Sink`","ref":"Membrane.HTTPAdaptiveStream.Sink.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Sink.ManifestConfig","doc":"`Membrane.HTTPAdaptiveStream.Manifest` configuration.","ref":"Membrane.HTTPAdaptiveStream.Sink.ManifestConfig.html"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Sink.ManifestConfig.t/0","doc":"Manifest configuration consists of the following fields:\n- `name` - name of the main manifest file.\n- `module` - implementation of the `Membrane.HTTPAdaptiveStream.Manifest` behaviour.","ref":"Membrane.HTTPAdaptiveStream.Sink.ManifestConfig.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Sink.TrackConfig","doc":"Track configuration. For more information checkout `Membrane.HTTPAdaptiveStream.Manifest.Track.Config`","ref":"Membrane.HTTPAdaptiveStream.Sink.TrackConfig.html"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Sink.TrackConfig.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Sink.TrackConfig.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.SinkBin","doc":"Bin responsible for receiving audio and video streams, performing payloading and CMAF muxing\nto eventually store them using provided storage configuration.","ref":"Membrane.HTTPAdaptiveStream.SinkBin.html"},{"type":"module","title":"Input streams - Membrane.HTTPAdaptiveStream.SinkBin","doc":"Parsed H264 or AAC video or audio streams are expected to be connected via the `:input` pad.\nThe type of stream has to be specified via the pad's `:encoding` option.","ref":"Membrane.HTTPAdaptiveStream.SinkBin.html#module-input-streams"},{"type":"module","title":"Output - Membrane.HTTPAdaptiveStream.SinkBin","doc":"Specify one of `Membrane.HTTPAdaptiveStream.Storages` as `:storage` to configure the sink.","ref":"Membrane.HTTPAdaptiveStream.SinkBin.html#module-output"},{"type":"module","title":"Bin options - Membrane.HTTPAdaptiveStream.SinkBin","doc":"Passed via struct `t:Membrane.HTTPAdaptiveStream.SinkBin.t/0`\n\n- `manifest_name`  \n\n  ```\n  String.t()\n  ```\n  \n  Default value: `\"index\"`  \n  Name of the main manifest file\n\n\n- `manifest_module`  \n\n  ```\n  module\n  ```\n  \n  ***Required***  \n  Implementation of the `Membrane.HTTPAdaptiveStream.Manifest`\n  behaviour.\n\n\n\n- `storage`  \n\n  ```\n  Storage.config_t()\n  ```\n  \n  ***Required***  \n  Storage configuration. May be one of `Membrane.HTTPAdaptiveStream.Storages.*`.\n  See `Membrane.HTTPAdaptiveStream.Storage` behaviour.\n\n\n\n- `target_window_duration`  \n\n  ```\n  Time.t() | :infinity\n  ```\n  \n  Default value: `40 |> Membrane.Time.seconds()`  \n  Manifest duration is kept above that time, while the oldest segments\n  are removed whenever possible.\n\n\n\n- `persist?`  \n\n  ```\n  boolean\n  ```\n  \n  Default value: `false`  \n  If true, stale segments are removed from the manifest only. Once\n  playback finishes, they are put back into the manifest.\n\n\n\n- `mode`  \n\n  ```\n  :live | :vod\n  ```\n  \n  Default value: `:vod`  \n  Tells if the session is live or a VOD type of broadcast. It can influence type of metadata\n  inserted into the playlist's manifest.\n\n\n\n- `hls_mode`  \n\n  ```\n  :muxed_av | :separate_av\n  ```\n  \n  Default value: `:separate_av`  \n  Option defining how the incoming tracks will be handled and how CMAF will be muxed.\n  \n  - In `:muxed_av` audio will be added to each video rendition, creating CMAF segments that contain both audio and video.\n  - In `:separate_av` audio and video tracks will be separate and synchronization will need to be sorted out by the player.\n\n\n\n- `header_naming_fun`  \n\n  ```\n  (Manifest.Track.t(), counter :: non_neg_integer() -> String.t())\n  ```\n  \n  Default value: `&Membrane.HTTPAdaptiveStream.Manifest.Track.default_header_naming_fun/2`  \n  A function that generates consequent media header names for a given track\n\n\n\n- `segment_naming_fun`  \n\n  ```\n  (Manifest.Track.t() -> String.t())\n  ```\n  \n  Default value: `&Membrane.HTTPAdaptiveStream.Manifest.Track.default_segment_naming_fun/1`  \n  A function that generates consequent segment names for a given track\n\n\n\n- `mp4_parameters_in_band?`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `false`  \n  Determines whether the parameter type nalus will be removed from the stream.\n  Inband parameters seem to be legal with MP4, but some players don't respond kindly to them, so use at your own risk.\n  This parameter should be set to true when discontinuity can occur. For example when resolution can change.\n\n\n\n- `cleanup_after`  \n\n  ```\n  nil | Time.t()\n  ```\n  \n  Default value: `nil`  \n  Time after which a fire-and-forget storage cleanup function should run.\n  \n  The function will remove all manifests and segments stored during the stream.","ref":"Membrane.HTTPAdaptiveStream.SinkBin.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.HTTPAdaptiveStream.SinkBin","doc":"### `:input`\n\nAccepted formats:\n```\nMembrane.AAC\n```\n```\nMembrane.H264\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nPad options:\n\n- `encoding`  \n\n  ```\n  :AAC | :H264\n  ```\n  \n  ***Required***  \n  Encoding type determining which parser will be used for the given stream.\n\n\n- `track_name`  \n\n  ```\n  String.t() | nil\n  ```\n  \n  Default value: `nil`  \n  Name that will be used to name the media playlist for the given track, as well as its header and segments files.\n  It must not contain any URI reserved characters\n\n\n\n- `segment_duration`  \n\n  ```\n  Membrane.Time.t()\n  ```\n  \n  ***Required***  \n  The minimal segment duration of the regular segments.\n\n\n\n- `partial_segment_duration`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  The segment duration of the partial segments.\n  If not set then the bin won't produce any partial segments.\n\n\n\n- `max_framerate`  \n\n  ```\n  float() | nil\n  ```\n  \n  Default value: `nil`  \n  The maximal framerate of video variant. This information is used in master playlist.\n  \n  When set to nil then this information won't be added to master playlist. For audio it should be set to nil.","ref":"Membrane.HTTPAdaptiveStream.SinkBin.html#module-pads"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.SinkBin.options/0","doc":"Returns description of options available for this module","ref":"Membrane.HTTPAdaptiveStream.SinkBin.html#options/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.SinkBin.input_pad_opts/0","doc":"Options for pad `:input`","ref":"Membrane.HTTPAdaptiveStream.SinkBin.html#t:input_pad_opts/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.SinkBin.t/0","doc":"Struct containing options for `Membrane.HTTPAdaptiveStream.SinkBin`","ref":"Membrane.HTTPAdaptiveStream.SinkBin.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.HLS","doc":"`Membrane.HTTPAdaptiveStream.Manifest` implementation for HTTP Live Streaming.\n\nCurrently supports up to one audio and video stream.","ref":"Membrane.HTTPAdaptiveStream.HLS.html"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.HLS.serialize/1","doc":"Generates EXTM3U playlist for the given manifest","ref":"Membrane.HTTPAdaptiveStream.HLS.html#serialize/1"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.HLS.SegmentAttribute","doc":"Implementation of `Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute` behaviour for HTTP Live Streaming","ref":"Membrane.HTTPAdaptiveStream.HLS.SegmentAttribute.html"},{"type":"behaviour","title":"Membrane.HTTPAdaptiveStream.Manifest","doc":"Behaviour for manifest serialization.","ref":"Membrane.HTTPAdaptiveStream.Manifest.html"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.add_chunk/3","doc":"Adds segment to the manifest. In case of ll-hls it will add partial segment, and also full segment if needed.\nReturns `Membrane.HTTPAdaptiveStream.Manifest.Track.Changeset`.","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#add_chunk/3"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.add_track/2","doc":"Add a track to the manifest.\n\nReturns the name under which the header file should be stored.","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#add_track/2"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.discontinue_track/2","doc":"Append a discontinuity to the track.\n\nThis will inform the player that eg. the parameters of the encoder changed and allow you to provide a new MP4 header.\nFor details on discontinuities refer to [RFC 8216](https://datatracker.ietf.org/doc/html/rfc8216).","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#discontinue_track/2"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.finish/2","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#finish/2"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.from_beginning/1","doc":"Filter all tracks that have option `:persisted?` set to true, then\nrestores all the stale segments in those tracks.","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#from_beginning/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.has_track?/2","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#has_track?/2"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.header_per_track/1","doc":"Returns one header per track","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#header_per_track/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.persisted?/2","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#persisted?/2"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.segments_per_track/1","doc":"Returns all segments grouped by the track id.","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#segments_per_track/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.serialize/1","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#serialize/1"},{"type":"callback","title":"Membrane.HTTPAdaptiveStream.Manifest.serialize/1","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#c:serialize/1"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.serialized_manifest_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#t:serialized_manifest_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.serialized_manifests_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#t:serialized_manifests_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Manifest.Changeset","doc":"Structure representing changes that has been applied to the track. What element has been added\nand what elements are to be removed.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.html"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.merge/2","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.html#merge/2"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.element_type_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.html#t:element_type_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.Segment","doc":"Type used to recognize `to_add` segments in Changeset.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.Segment.html"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.Segment.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Changeset.Segment.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Manifest.Segment","doc":"Structure representing a single manifest segment.\n\n\nIt stores the following fields:\n* `name` - the segment's name\n* `duration` - the segment's total duration\n* `size` - the byte size of the segment payload\n* `attributes` - the meta attributes associated with the segment\n* `type` - decides if the structure is a full segment that can exist on its own\n           or if it hosts and awaits more partial segments\n* `parts` - the partial segments making up the full segment","ref":"Membrane.HTTPAdaptiveStream.Manifest.Segment.html"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Segment.partial_segment_t/0","doc":"Structure of partial segment.\n\nAttributes representing a partial segment:\n* `independent?` - decides if a segment can be played on its own e.g. starts with a keyframe or is an audio sample\n* `duration` - the duration of the partial segment\n* `attributes` - the attributes for the particular partial segment","ref":"Membrane.HTTPAdaptiveStream.Manifest.Segment.html#t:partial_segment_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Segment.segment_duration_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Segment.html#t:segment_duration_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Segment.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Segment.html#t:t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Segment.type_t/0","doc":"Determines if segment is full and independent or partial\nand consists of several partial segments.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Segment.html#t:type_t/0"},{"type":"behaviour","title":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute","doc":"Definition of Segment Attributes and behaviour for serializing them.\nThis module should also contain macros for generating different types of attributes","ref":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute.html"},{"type":"macro","title":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute.discontinuity/2","doc":"Creates a definition of a discontinuity segment attribute.","ref":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute.html#discontinuity/2"},{"type":"callback","title":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute.serialize/1","doc":"Callback for serializing a segment attribute to a string. It is required for each implementation of this behavior.","ref":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute.html#c:serialize/1"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute.segment_type_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute.html#t:segment_type_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.SegmentAttribute.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Manifest.Track","doc":"Struct representing a state of a single manifest track and functions to operate\non it.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.add_chunk/3","doc":"Recognizes if its regular or partial segment and then update the track appropriately.\nReturns `Changeset`.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#add_chunk/3"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.all_segments/1","doc":"Returns all segments present in the track, including stale segments.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#all_segments/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.default_header_naming_fun/2","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#default_header_naming_fun/2"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.default_partial_naming_fun/2","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#default_partial_naming_fun/2"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.default_segment_naming_fun/1","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#default_segment_naming_fun/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.discontinue/1","doc":"Discontinue the track, indicating that parameters of the stream have changed.\n\nNew header has to be stored under the returned filename.\nFor details on discontinuity, please refer to [RFC 8216](https://datatracker.ietf.org/doc/html/rfc8216).","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#discontinue/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.finish/1","doc":"Marks the track as finished and finalize last segment if needed. After this action, it won't be possible to add any new segments to the track.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#finish/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.from_beginning/1","doc":"Return new track with all stale segments restored, resulting in playback of historic data.\nOnly works with 'persist?' option enabled.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#from_beginning/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.header/1","doc":"Returns current header name","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#header/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.new/1","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#new/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.persisted?/1","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#persisted?/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.supports_partial_segments?/1","doc":"Tells whether the track is able to produce partial media segments.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#supports_partial_segments?/1"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.id_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#t:id_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.segment_duration_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#t:segment_duration_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.segment_metadata/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#t:segment_metadata/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.segment_payload_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#t:segment_payload_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.segment_size_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#t:segment_size_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.segments_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#t:segments_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.t/0","doc":"The struct representing a track.\n\nConsists of all the fields from `Config.t` and also:\n- `header_name` - name of the header file\n- `current_seq_num` - the number to identify the next segment\n- `current_discontinuity_seq_num` - number of current discontinuity sequence.\n- `segments` - segments' names and durations\n- `stale_segments` - stale segments' names and durations, kept empty unless `persist?` is set to true\n- `stale_headers` - stale headers' names, kept empty unless `persist?` is set to true\n- `finished?` - determines whether the track is finished\n- `window_duration` - current window duration\n- `discontinuities_counter` - the number of discontinuities that happened so far\n- `next_segment_id` - the sequence number of the next segment that will be generated\n- `segment_sequencer` - keeps track of the current sequence number of a segment.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.Config","doc":"Track configuration.","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.Config.html"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.Config.encoding_t/0","doc":"Track configuration consists of the following fields:\n- `id` - identifies the track, will be serialized and attached to names of manifests, headers and segments\n- `track_name` - the name of the track, determines how manifest files will be named\n- `content_type` - either audio or video\n- `header_extension` - extension of the header file (for example .mp4 for CMAF)\n- `segment_extension` - extension of the segment files (for example .m4s for CMAF)\n- `segment_duration` - expected duration of segments.\n- `partial_segment_duration` - expected duration of each partial segment, nil if not partial segments are expected\n- `header_naming_fun` - a function that generates consequent header names for a given track\n- `segment_naming_fun` - a function that generates consequent segment names for a given track\n- `target_window_duration` - track manifest duration is kept above that time, while the oldest segments\n            are removed whenever possible\n- `persist?` - determines whether the entire track contents should be available after the streaming finishes\n- `mode` - track's mode that dictates type of metadata inserted into playlist's manifest\n- `encoding` - keyword of strings representing encoding of content_type\n- `resolution` - resolution of video stream\n- `max_framerate` - maximal framerate of video stream","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.Config.html#t:encoding_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Manifest.Track.Config.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Manifest.Track.Config.html#t:t/0"},{"type":"behaviour","title":"Membrane.HTTPAdaptiveStream.Storage","doc":"Behaviour for storing manifests and stream segments.","ref":"Membrane.HTTPAdaptiveStream.Storage.html"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Storage.apply_track_changeset/3","doc":"Stores a new segment and removes stale ones.","ref":"Membrane.HTTPAdaptiveStream.Storage.html#apply_track_changeset/3"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Storage.clean_all_tracks/3","doc":"Removes all segments grouped by track.","ref":"Membrane.HTTPAdaptiveStream.Storage.html#clean_all_tracks/3"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Storage.cleanup/4","doc":"Removes all the saved segments and manifest for given id.","ref":"Membrane.HTTPAdaptiveStream.Storage.html#cleanup/4"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Storage.clear_cache/1","doc":"Clears the manifest cache.","ref":"Membrane.HTTPAdaptiveStream.Storage.html#clear_cache/1"},{"type":"callback","title":"Membrane.HTTPAdaptiveStream.Storage.init/1","doc":"Generates the storage state based on the configuration struct.","ref":"Membrane.HTTPAdaptiveStream.Storage.html#c:init/1"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Storage.new/2","doc":"Initializes the storage.\n\nAccepts the following options:\n- `enable_cache` - if true (default), manifests will be stored only if they've been changed","ref":"Membrane.HTTPAdaptiveStream.Storage.html#new/2"},{"type":"callback","title":"Membrane.HTTPAdaptiveStream.Storage.remove/4","doc":"Removes the resource.\n\nIn case of removing a segment the storage should make sure to remove all\nprevious partial segments with the same name. It is the user's responsibility to remember\nand distinguish between the partial segments.","ref":"Membrane.HTTPAdaptiveStream.Storage.html#c:remove/4"},{"type":"callback","title":"Membrane.HTTPAdaptiveStream.Storage.store/6","doc":"Stores the resource on a storage.\n\nGets the mode that should be used when writing to a file and type of the resource","ref":"Membrane.HTTPAdaptiveStream.Storage.html#c:store/6"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Storage.store_header/4","doc":"Stores stream header file.","ref":"Membrane.HTTPAdaptiveStream.Storage.html#store_header/4"},{"type":"function","title":"Membrane.HTTPAdaptiveStream.Storage.store_manifests/2","doc":"Stores serialized manifest files","ref":"Membrane.HTTPAdaptiveStream.Storage.html#store_manifests/2"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storage.callback_result_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:callback_result_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storage.config_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:config_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storage.header/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:header/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storage.metadata_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:metadata_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storage.parent_t/0","doc":"The identifier of a parent that the resource belongs to (the track identifier).\n\nIt can either be a master or secondary playlist (a track playlist).\nIn case of master playlist the identifier will be `:master`  while for tracks it can be an arbitrary value.","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:parent_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storage.partial_segment_metadata/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:partial_segment_metadata/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storage.segment_metadata_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:segment_metadata_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storage.segments/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:segments/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storage.state_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:state_t/0"},{"type":"opaque","title":"Membrane.HTTPAdaptiveStream.Storage.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storage.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Storages.FileStorage","doc":"`Membrane.HTTPAdaptiveStream.Storage` implementation that saves the stream to\nfiles locally.","ref":"Membrane.HTTPAdaptiveStream.Storages.FileStorage.html"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storages.FileStorage.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storages.FileStorage.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage","doc":"`Membrane.HTTPAdaptiveStream.Storage` implementation that issues a call or cast\nwith a `t:message_t/0` to given destination on each call to store/remove.","ref":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage.html"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage.message_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage.html#t:message_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage.remove_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage.html#t:remove_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage.store_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage.html#t:store_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storages.GenServerStorage.html#t:t/0"},{"type":"module","title":"Membrane.HTTPAdaptiveStream.Storages.SendStorage","doc":"`Membrane.HTTPAdaptiveStream.Storage` implementation that sends a `t:message_t/0`\nto given destination on each call to store/remove.","ref":"Membrane.HTTPAdaptiveStream.Storages.SendStorage.html"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storages.SendStorage.message_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storages.SendStorage.html#t:message_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storages.SendStorage.remove_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storages.SendStorage.html#t:remove_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storages.SendStorage.store_t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storages.SendStorage.html#t:store_t/0"},{"type":"type","title":"Membrane.HTTPAdaptiveStream.Storages.SendStorage.t/0","doc":"","ref":"Membrane.HTTPAdaptiveStream.Storages.SendStorage.html#t:t/0"},{"type":"extras","title":"Membrane HTTP Adaptive Streaming Plugin","doc":"# Membrane HTTP Adaptive Streaming Plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_http_adaptive_stream_plugin.svg)](https://hex.pm/packages/membrane_http_adaptive_stream_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_http_adaptive_stream_plugin/)\n[![CircleCI](https://circleci.com/gh/membraneframework/membrane_http_adaptive_stream_plugin.svg?style=svg)](https://circleci.com/gh/membraneframework/membrane_http_adaptive_stream_plugin)\n\nPlugin generating manifests for HTTP adaptive streaming protocols.\nCurrently, only HTTP Live Streaming (HLS) is supported.\nIn future, the support for MPEG-DASH is planned as well","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane HTTP Adaptive Streaming Plugin","doc":"Add the following line to your `deps` in `mix.exs`. Run `mix deps.get`.\n\n```elixir\n\t{:membrane_http_adaptive_stream_plugin, \"~> 0.18.3\"}\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage Example - Membrane HTTP Adaptive Streaming Plugin","doc":"See `test/membrane_http_adaptive_stream/integration_test/sink_bin_integration_test.exs` pipeline for details on how to use HLS plugin and generate HLS playlists for example media tracks.\nMaster and media playlists with related multimedia content that were generated via this pipeline are stored in `test/membrane_http_adaptive_stream/integration_test/fixtures` directory.","ref":"readme.html#usage-example"},{"type":"extras","title":"Copyright and License - Membrane HTTP Adaptive Streaming Plugin","doc":"Copyright 2019, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_http_adaptive_stream_plugin)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_http_adaptive_stream_plugin)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2018 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}